==> gcube-portal-bundle-4.4.0-20170627.153617-17.tar.gz: org/gcube/common/portal/GCubePortalConstants.java <==
package org.gcube.common.portal;


public class GCubePortalConstants {
	public static final String PREFIX_GROUP_URL = "/group";
	public static final String GUEST_GROUP_FRIENDLY_URL = "/guest";
	public static final String USER_PROFILE_FRIENDLY_URL = "/profile";
	public static final String GROUP_MEMBERS_FRIENDLY_URL = "/members";
	public static final String USER_NOTIFICATION_FRIENDLY_URL = "/notifications";
	public static final String USER_WORKSPACE_FRIENDLY_URL = "/workspace";
	public static final String USER_MESSAGES_FRIENDLY_URL = "/messages";
	public static final String VRES_EXPLORE_FRIENDLY_URL = "/explore";
	public static final String CATALOGUE_FRIENDLY_URL = "/data-catalogue";
	public static final String AUTHORIZATION_FRIENDLY_URL = "/authorization";	
	public static final String MANAGE_USERS_REQUESTS_FRIENDLY_URL = "/manage-user-and-requests";
	public static final String VRE_ADMINISTRATION_URL = "/administration";
	
	public static final String INFRASTRUCTURE_NAME = "infrastructure";  
	public static final String SCOPES = "scopes";
	public static final String PORTAL_APPLICATION_TOKEN = "portalAuthToken";  
	public static final String ICPROXY_ENDPOINT_URL = "ic-proxy-endpointURL";  
	public static final String SENDER_EMAIL = "notificationSenderEmail";
	public static final String GATEWAY_NAME = "portalinstancename";
	public static final String ADMIN_USERNAME = "administratorUsername";
	
	public static final String VRE_ID_ATTR_NAME = "gcube-vreid";
	public static final String USER_ID_ATTR_NAME = "gcube-userId";
}

==> gcube-portal-bundle-4.5.0-20180619.054858-17.tar.gz: org/gcube/common/portal/GCubePortalConstants.java <==
package org.gcube.common.portal;


public class GCubePortalConstants {
	public static final String PREFIX_GROUP_URL = "/group";
	public static final String GUEST_GROUP_FRIENDLY_URL = "/guest";
	public static final String USER_PROFILE_FRIENDLY_URL = "/profile";
	public static final String GROUP_MEMBERS_FRIENDLY_URL = "/members";
	public static final String USER_NOTIFICATION_FRIENDLY_URL = "/notifications";
	public static final String USER_WORKSPACE_FRIENDLY_URL = "/workspace";
	public static final String USER_MESSAGES_FRIENDLY_URL = "/messages";
	public static final String VRES_EXPLORE_FRIENDLY_URL = "/explore";
	public static final String CATALOGUE_FRIENDLY_URL = "/data-catalogue";
	public static final String QUESTIONNAIRE_MANAGER_FRIENDLY_URL = "/questionnaire-manager";
	public static final String QUESTIONNAIRE_TAKE_FRIENDLY_URL = "/take-the-survey";
	public static final String AUTHORIZATION_FRIENDLY_URL = "/authorization";	
	public static final String MANAGE_USERS_REQUESTS_FRIENDLY_URL = "/manage-user-and-requests";
	public static final String VRE_ADMINISTRATION_URL = "/administration";
	
	public static final String INFRASTRUCTURE_NAME = "infrastructure";  
	public static final String SCOPES = "scopes";
	public static final String PORTAL_APPLICATION_TOKEN = "portalAuthToken";  
	public static final String ICPROXY_ENDPOINT_URL = "ic-proxy-endpointURL";  
	public static final String SENDER_EMAIL = "notificationSenderEmail";
	public static final String GATEWAY_NAME = "portalinstancename";
	public static final String ADMIN_USERNAME = "administratorUsername";
	
	public static final String VRE_ID_ATTR_NAME = "gcube-vreid";
	public static final String USER_ID_ATTR_NAME = "gcube-userId";
}
